<?xml version="1.0" encoding="ISO-8859-1"?>
<!--
Copyright (C) 2010  Paul Wolneykien <manowar@altlinux.org>

This file is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
-->
<xsl:stylesheet version="1.0"
	        xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
<xsl:template name="add-and-bind-host">
  <xsl:param name="typename" />
  <xsl:param name="groupname" />
  <xsl:call-template name="add-unbinded-host" />
  <xsl:call-template name="add-groups-bind-host">
    <xsl:with-param name="groups" select="$groupname" />
  </xsl:call-template>
  <xsl:call-template name="link-template">
    <xsl:with-param name="template-name" select="$typename" />
  </xsl:call-template>
</xsl:template>
<xsl:template name="add-groups-bind-host">
  <xsl:param name="groups" />
  <xsl:if test="$groups">
    <xsl:choose>
      <xsl:when test="contains($groups, ',')">
	<xsl:call-template name="add-group-bind-host">
	  <xsl:with-param name="groupname" select="normalize-space(substring-before($groups, ','))" />
	</xsl:call-template>
	<xsl:call-template name="add-groups-bind-host">
	  <xsl:with-param name="groups" select="normalize-space(substring-after($groups, ','))" />
	</xsl:call-template>
      </xsl:when>
      <xsl:otherwise>
	<xsl:call-template name="add-group-bind-host">
	  <xsl:with-param name="groupname" select="normalize-space($groups)" />
	</xsl:call-template>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:if>
</xsl:template>
<xsl:template name="add-group-bind-host">
  <xsl:param name="groupname" />
  <xsl:call-template name="add-group">
    <xsl:with-param name="name" select="$groupname" />
  </xsl:call-template>
  <xsl:call-template name="bind-host-group">
    <xsl:with-param name="hostname" select="name" />
    <xsl:with-param name="groupname" select="$groupname" />
  </xsl:call-template>
</xsl:template>
<xsl:template name="add-host">
  <xsl:choose>
    <xsl:when test="type != '' and group != ''">
      <xsl:call-template name="add-and-bind-host">
	<xsl:with-param name="typename" select="type" />
	<xsl:with-param name="groupname" select="group" />
      </xsl:call-template>
    </xsl:when>
    <xsl:when test="type != '' and group = ''">
      <xsl:call-template name="add-and-bind-host">
	<xsl:with-param name="typename" select="type" />
	<xsl:with-param name="groupname" select="../@group" />
      </xsl:call-template>
    </xsl:when>
    <xsl:when test="type = '' and group != ''">
      <xsl:call-template name="add-and-bind-host">
	<xsl:with-param name="typename" select="../@type" />
	<xsl:with-param name="groupname" select="group" />
      </xsl:call-template>
    </xsl:when>
    <xsl:otherwise>
      <xsl:call-template name="add-and-bind-host">
	<xsl:with-param name="typename" select="../@type" />
	<xsl:with-param name="groupname" select="../@group" />
      </xsl:call-template>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>
<xsl:template name="add-link-triggers">
  <xsl:param name="map" />
  <xsl:param name="host-1" />
  <xsl:param name="host-2" />
  <xsl:param name="triggers" select="$link-triggers" />
  <xsl:if test="$triggers">
    <xsl:choose>
      <xsl:when test="contains($triggers, ',')">
	<xsl:call-template name="add-trigger-to-link">
	  <xsl:with-param name="map" select="$map" />
	  <xsl:with-param name="host-1" select="$host-1" />
	  <xsl:with-param name="host-2" select="$host-2" />
	  <xsl:with-param name="trigger" select="normalize-space(substring-before($triggers, ','))" />
	</xsl:call-template>
	<xsl:call-template name="add-link-triggers">
	  <xsl:with-param name="map" select="$map" />
	  <xsl:with-param name="host-1" select="$host-1" />
	  <xsl:with-param name="host-2" select="$host-2" />
	  <xsl:with-param name="triggers" select="normalize-space(substring-after($triggers, ','))" />
	</xsl:call-template>
      </xsl:when>
      <xsl:otherwise>
	<xsl:call-template name="add-trigger-to-link">
	  <xsl:with-param name="map" select="$map" />
	  <xsl:with-param name="host-1" select="$host-1" />
	  <xsl:with-param name="host-2" select="$host-2" />
	  <xsl:with-param name="trigger" select="normalize-space($triggers)" />
	</xsl:call-template>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:if>
</xsl:template>
<xsl:template name="add-link-triggers-by-items">
  <xsl:param name="map" />
  <xsl:param name="host-1" />
  <xsl:param name="host-2" />
  <xsl:param name="items" select="$link-trigger-items" />
  <xsl:if test="$items">
    <xsl:choose>
      <xsl:when test="contains($items, ',')">
	<xsl:call-template name="add-trigger-to-link">
	  <xsl:with-param name="map" select="$map" />
	  <xsl:with-param name="host-1" select="$host-1" />
	  <xsl:with-param name="host-2" select="$host-2" />
	  <xsl:with-param name="item" select="normalize-space(substring-before($items, ','))" />
	</xsl:call-template>
	<xsl:call-template name="add-link-triggers-by-items">
	  <xsl:with-param name="map" select="$map" />
	  <xsl:with-param name="host-1" select="$host-1" />
	  <xsl:with-param name="host-2" select="$host-2" />
	  <xsl:with-param name="items" select="normalize-space(substring-after($items, ','))" />
	</xsl:call-template>
      </xsl:when>
      <xsl:otherwise>
	<xsl:call-template name="add-trigger-to-link">
	  <xsl:with-param name="map" select="$map" />
	  <xsl:with-param name="host-1" select="$host-1" />
	  <xsl:with-param name="host-2" select="$host-2" />
	  <xsl:with-param name="item" select="normalize-space($items)" />
	</xsl:call-template>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:if>
</xsl:template>
<xsl:template name="mirror-items">
  <xsl:param name="items" />
  <xsl:if test="$items">
    <xsl:choose>
      <xsl:when test="contains($items, ',')">
	<xsl:call-template name="add-mirror-item">
	  <xsl:with-param name="key" select="normalize-space(substring-before($items, ','))" />
	</xsl:call-template>
	<xsl:call-template name="mirror-items">
	  <xsl:with-param name="items" select="normalize-space(substring-after($items, ','))" />
	</xsl:call-template>
      </xsl:when>
      <xsl:otherwise>
	<xsl:call-template name="add-mirror-item">
	  <xsl:with-param name="key" select="normalize-space($items)" />
	</xsl:call-template>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:if>
</xsl:template>
</xsl:stylesheet>
